# Installation
> `npm install --save @types/plotly.js`

# Summary
This package contains type definitions for plotly.js (https://plot.ly/javascript/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/plotly.js.

### Additional Details
 * Last updated: Sat, 20 Dec 2025 18:39:01 GMT
 * Dependencies: none

# Credits
These definitions were written by [Chris Gervang](https://github.com/chrisgervang), [Martin Duparc](https://github.com/martinduparc), [Frederik Aalund](https://github.com/frederikaalund), [taoqf](https://github.com/taoqf), [Dadstart](https://github.com/Dadstart), [Jared Szechy](https://github.com/szechyjs), [Sooraj Pudiyadath](https://github.com/soorajpudiyadath), [Jon Freedman](https://github.com/jonfreedman), [Megan Riel-Mehan](https://github.com/meganrm), [Josh Miles](https://github.com/milesjos), [Pramod Mathai ](https://github.com/skippercool), [Michael Arnett](https://github.com/marnett-git), [Piotr Błażejewicz](https://github.com/peterblazejewicz), [Brandon Mitchell](https://github.com/brammitch), [Jessica Blizzard](https://github.com/blizzardjessica), [Oleg Shilov](https://github.com/olegshilov), [Pablo Gracia](https://github.com/PabloGracia), [Jeffrey van Gogh](https://github.com/jvgogh), [John Abdou](https://github.com/jpabdou), and [Martin Borst](https://github.com/mrtnbrst).
